@@ -44,16 +44,21 @@ public:
 	NCXReader(BookReader &modelReader);
 	const std::map<int,NavPoint> &navigationMap() const;
 
-private:
+protected:
 	void startElementHandler(const char *tag, const char **attributes);
 	void endElementHandler(const char *tag);
 	void characterDataHandler(const char *text, size_t len);
+	void namespaceListChangedHandler();
+	bool processNamespaces() const;
+
+private:
 	const std::vector<std::string> &externalDTDs() const;
 
 private:
 	BookReader &myModelReader;
 	std::map<int,NavPoint> myNavigationMap;
 	std::vector<NavPoint> myPointStack;
+	std::string myNCXNamespacePrefix;
 
 	enum {
 		READ_NONE,
