@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,10 +31,14 @@ class PdbStream : public ZLInputStream {
 public:
 	PdbStream(ZLFile &file);
 	virtual ~PdbStream();
-	size_t read(char *buffer, size_t maxSize);
+
+protected:
 	virtual bool open();
 	virtual void close();
 
+private:
+	size_t read(char *buffer, size_t maxSize);
+
 	void seek(int offset, bool absoluteOffset);
 	size_t offset() const;
 	size_t sizeOfOpened();
@@ -42,14 +46,27 @@ public:
 protected:
 	virtual bool fillBuffer() = 0;
 
+protected:
+	size_t recordOffset(size_t index) const;
+
+public:
+	const PdbHeader &header() const;
+
 protected:
 	shared_ptr<ZLInputStream> myBase;
 	size_t myOffset;
-	PdbHeader myHeader;
-	char *myBuffer;
 
+private:
+	PdbHeader myHeader;
+	
+protected:
+	char *myBuffer;
 	unsigned short myBufferLength;
 	unsigned short myBufferOffset;
 };
 
+inline const PdbHeader &PdbStream::header() const {
+	return myHeader;
+}
+
 #endif /* __PDBSTREAM_H__ */
